// Copyright (c) Corporation for National Research Initiatives
package org.python.parser;

public class Visitor {
    public Object single_input(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object file_input(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object eval_input(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object funcdef(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object varargslist(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object ExtraArgList(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object ExtraKeywordList(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object defaultarg(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object fplist(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object expr_stmt(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object print_stmt(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object print_ext(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object del_stmt(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object pass_stmt(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object break_stmt(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object continue_stmt(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object return_stmt(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object raise_stmt(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object Import(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object ImportFrom(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object dotted_name(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object global_stmt(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object exec_stmt(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object assert_stmt(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object if_stmt(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object while_stmt(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object for_stmt(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object try_stmt(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object except_clause(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object suite(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object or_boolean(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object and_boolean(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object not_1op(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object comparision(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object less_cmp(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object greater_cmp(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object equal_cmp(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object greater_equal_cmp(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object less_equal_cmp(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object notequal_cmp(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object in_cmp(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object not_in_cmp(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object is_not_cmp(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object is_cmp(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object or_2op(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object xor_2op(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object and_2op(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object lshift_2op(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object rshift_2op(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object add_2op(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object sub_2op(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object mul_2op(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object div_2op(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object mod_2op(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object pos_1op(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object neg_1op(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object invert_1op(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object pow_2op(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object Call_Op(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object Index_Op(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object Dot_Op(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object tuple(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object list(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object list_iter(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object dictionary(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object str_1op(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object strjoin(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object lambdef(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object Ellipses(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object Slice(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object Colon(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object Comma(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object classdef(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object arglist(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object Keyword(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object Int(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object Float(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object Complex(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object Name(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object String(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object augassign(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object aug_plus(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object aug_minus(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object aug_multiply(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object aug_divide(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object aug_modulo(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object aug_and(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object aug_or(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object aug_xor(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object aug_lshift(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object aug_rshift(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }

    public Object aug_power(SimpleNode n) throws Exception {
        throw new ParseException("Unhandled Node: "+n);
    }
}
